@@ -57,8 +57,16 @@ _script_dir = _os.path.dirname(_os.path.realpath(__file__))
 try:
     _Main.include(_os.path.join(_script_dir, "setup.jl"))
 except ImportError as err:
+    msg = str(err)
+
     # Trim Julia stacktrace from message
-    msg = str(err).split("\n")[0]
+    # Message format depends on PyCall version
+    if msg.startswith("Julia exception"):  # pragma: no cover
+        line_index = 0
+    else:
+        line_index = 1
+    msg = str(err).split("\n")[line_index]
+
     from future.utils import raise_from
     raise_from(ImportError(msg), None)
 
@@ -90,6 +98,7 @@ from .optimaltrees import *
 from .optimpute import *
 from .optimalfeatureselection import *
 from .rewardestimation import *
+from .heuristics import *
 
 
 def read_json(filename):
@@ -139,6 +148,18 @@ def read_json(filename):
             lnr = MeanImputationLearner()
         elif _Main.isa(jl_obj, _IAI.RandImputationLearner):
             lnr = RandImputationLearner()
+        elif (not _iai_version_less_than("2.1.0") and
+              _Main.isa(jl_obj, _IAI.RandomForestClassifier)):
+            lnr = RandomForestClassifier()
+        elif (not _iai_version_less_than("2.1.0") and
+              _Main.isa(jl_obj, _IAI.RandomForestRegressor)):
+            lnr = RandomForestRegressor()
+        elif (not _iai_version_less_than("2.1.0") and
+              _Main.isa(jl_obj, _IAI.XGBoostClassifier)):
+            lnr = XGBoostClassifier()
+        elif (not _iai_version_less_than("2.1.0") and
+              _Main.isa(jl_obj, _IAI.XGBoostRegressor)):
+            lnr = XGBoostRegressor()
 
         return lnr
 
