@@ -327,15 +327,27 @@ class GridSearch(Learner):
         jl_obj = _IAI.GridSearch_convert(lnr._jl_obj, *args, **kwargs)
         super().__init__(jl_obj)
 
+    def _warn_deprecated(self, name):
+        _warnings.warn(
+            "'{0}' is deprecated for 'GridSearch', use ".format(name) +
+            "'get_learner' followed by '{0}'".format(name),
+            FutureWarning
+        )
+
+    def _check_delegate(self, check_name, call_name):
+        # TODO is this the best way to do it? Some way of adding the task mixin
+        #      to the grid seems like it could be better
+        if not getattr(self._lnr_type(), check_name, None):
+            raise TypeError("GridSearch over " + self._lnr_type.__name__ +
+                            " does not support `{0}`.".format(call_name))
+
     # Fallback to hitting learner methods if not defined on grid search
     def __getattr__(self, item):
         if item in [
             "write_dot",
             "write_png",
-            "show_in_browser",
-            "write_html",
-            "show_questionnaire",
-            "write_questionnaire",
+            "write_pdf",
+            "write_svg",
             "Questionnaire",
             "get_classification_label",
             "get_classification_proba",
@@ -369,11 +381,7 @@ class GridSearch(Learner):
             "set_threshold",
         ]:  # pragma: no cover
             if _iai_version_less_than("2.0.0"):
-                _warnings.warn(
-                    "'{0}' is deprecated for 'GridSearch', use ".format(item) +
-                    "'get_learner' followed by '{0}'".format(item),
-                    FutureWarning
-                )
+                self._warn_deprecated(item)
             else:
                 raise AttributeError(
                     "'GridSearch' object has no attribute '{0}'".format(item),
@@ -456,13 +464,48 @@ class GridSearch(Learner):
         `data preparation <https://docs.interpretable.ai/v2.0.0/IAI-Python/data/#Python-Data-Preparation-Guide-1>`
         for information on how to format and supply the data.
         """
-        # TODO is this the best way to do it? Some way of adding the task mixin
-        #      to the grid seems like it could be better
-        if not getattr(self._lnr_type(), "fit_transform", None):
-            raise TypeError("GridSearch over " + self._lnr_type.__name__ +
-                            " does not support `fit_transform_cv`.")
+        self._check_delegate("fit_transform", "fit_transform_cv")
         return _IAI.fit_transform_cv_convert(self._jl_obj, *args, **kwargs)
 
+    def write_html(self, filename, **kwargs):
+        self._check_delegate("write_html", "write_html")
+        if _iai_version_less_than("2.0.0"):
+            self._warn_deprecated("write_html")
+            # IAI v1.0 doesn't define the forwarding method, so do it here
+            return _IAI.write_html_convert(filename,
+                                           self.get_learner()._jl_obj,
+                                           **kwargs)
+        return _IAI.write_html_convert(filename, self._jl_obj, **kwargs)
+
+    def show_in_browser(self, *args, **kwargs):  # pragma: no cover
+        self._check_delegate("show_in_browser", "show_in_browser")
+        if _iai_version_less_than("2.0.0"):
+            self._warn_deprecated("show_in_browser")
+            # IAI v1.0 doesn't define the forwarding method, so do it here
+            return _IAI.show_in_browser_convert(self.get_learner()._jl_obj,
+                                                *args, **kwargs)
+        return _IAI.show_in_browser_convert(self._jl_obj, *args, **kwargs)
+
+    def write_questionnaire(self, filename, **kwargs):
+        self._check_delegate("write_questionnaire", "write_questionnaire")
+        if _iai_version_less_than("2.0.0"):
+            self._warn_deprecated("write_questionnaire")
+            # IAI v1.0 doesn't define the forwarding method, so do it here
+            return _IAI.write_questionnaire_convert(filename,
+                                                    self.get_learner()._jl_obj,
+                                                    **kwargs)
+        return _IAI.write_questionnaire_convert(filename, self._jl_obj,
+                                                **kwargs)
+
+    def show_questionnaire(self, *args, **kwargs):  # pragma: no cover
+        self._check_delegate("show_questionnaire", "show_questionnaire")
+        if _iai_version_less_than("2.0.0"):
+            self._warn_deprecated("show_questionnaire")
+            # IAI v1.0 doesn't define the forwarding method, so do it here
+            return _IAI.show_questionnaire_convert(self.get_learner()._jl_obj,
+                                                   *args, **kwargs)
+        return _IAI.show_questionnaire_convert(self._jl_obj, *args, **kwargs)
+
 
 class ROCCurve():
     """Container for ROC curve information with the following fields:
@@ -514,6 +557,24 @@ class ROCCurve():
     def _repr_html_(self):
         return _IAI.to_html(self._jl_obj)
 
+    def write_html(self, filename, **kwargs):
+        """Write interactive browser visualization of the ROC curve to
+        `filename` as HTML.
+
+        Julia Equivalent:
+        `IAI.write_html <https://docs.interpretable.ai/v2.0.0/IAIBase/reference/#IAI.write_html>`
+
+        Examples
+        --------
+        >>> lnr.write_html(filename, **kwargs)
+
+        Compatibility
+        -------------
+        Requires IAI version 1.1 or higher.
+        """
+        _requires_iai_version("1.1.0", "write_html")
+        return _IAI.write_html_convert(filename, self._jl_obj, **kwargs)
+
     def show_in_browser(self, **kwargs):  # pragma: no cover
         """Visualize the ROC curve in the browser.
 
