@@ -1,4 +1,4 @@
-from .iai import _IAI, _requires_iai_version
+from .iai import _IAI, _requires_iai_version, GridSearch
 from .iaibase import (SupervisedLearner, ClassificationLearner,
                       RegressionLearner, SurvivalLearner, PrescriptionLearner,
                       PolicyLearner, SurvivalCurve)
@@ -306,6 +306,48 @@ class TreeLearner(SupervisedLearner):
         """
         return _IAI.write_png_convert(filename, self._jl_obj, **kwargs)
 
+    def write_pdf(self, filename, **kwargs):  # pragma: no cover
+        """Write learner to `filename` as a PDF image.
+
+        Requires
+        [GraphViz](http://www.graphviz.org/)
+        be installed and on the system `PATH`.
+
+        Julia Equivalent:
+        `IAI.write_pdf <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.write_pdf>`
+
+        Compatibility
+        -------------
+        Requires IAI version 2.1 or higher.
+
+        Examples
+        --------
+        >>> lnr.write_pdf(filename, **kwargs)
+        """
+        _requires_iai_version("2.1.0", "write_pdf")
+        return _IAI.write_pdf_convert(filename, self._jl_obj, **kwargs)
+
+    def write_svg(self, filename, **kwargs):  # pragma: no cover
+        """Write learner to `filename` as an SVG image.
+
+        Requires
+        [GraphViz](http://www.graphviz.org/)
+        be installed and on the system `PATH`.
+
+        Julia Equivalent:
+        `IAI.write_svg <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.write_svg>`
+
+        Compatibility
+        -------------
+        Requires IAI version 2.1 or higher.
+
+        Examples
+        --------
+        >>> lnr.write_svg(filename, **kwargs)
+        """
+        _requires_iai_version("2.1.0", "write_svg")
+        return _IAI.write_svg_convert(filename, self._jl_obj, **kwargs)
+
     def write_dot(self, filename, **kwargs):
         """Write learner to `filename` in
         [.dot format](http://www.graphviz.org/content/dot-language/).
@@ -659,54 +701,74 @@ class Questionnaire(AbstractVisualization):
 
 
 class MultiQuestionnaire(AbstractVisualization):
-    """Specify an interactive questionnaire of multiple tree learners as
-    specified by `questions`
+    """Specify an interactive questionnaire of multiple tree learners
 
     Julia Equivalent:
     `IAI.MultiQuestionnaire <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.MultiQuestionnaire>`
 
     Examples
     --------
-    >>> MultiQuestionnaire(questions)
-
-    Parameters
-    ----------
-    The questions to visualize. Refer to the
+    Constructs an interactive questionnaire using multiple tree learners from
+    specified questions. Refer to the
     `documentation on advanced tree visualization <https://docs.interpretable.ai/v2.0.0/IAI-Python/julia/#Python-Interactive-Visualizations-1>`
     for more information.
 
+    >>> MultiQuestionnaire(questions)
+
+    Constructs an interactive questionnaire containing the final fitted learner
+    from trained grid search as well as the learner found for each parameter
+    combination.
+
+    >>> MultiQuestionnaire(grid)
+
     Compatibility
     -------------
     Requires IAI version 1.1 or higher.
     """
-    def __init__(self, questions):
-        _requires_iai_version("1.1.0", "MultiQuestionnaire")
-        jl_obj = _IAI.MultiQuestionnaire_convert(questions)
+    def __init__(self, *args):
+        if len(args) > 0 and isinstance(args[0], GridSearch):
+            _requires_iai_version("2.0.0", "MultiQuestionnaire")
+            args = list(args)
+            grid = args.pop(0)
+            jl_obj = _IAI.MultiQuestionnaire_convert(grid._jl_obj, *args)
+        else:
+            _requires_iai_version("1.1.0", "MultiQuestionnaire")
+            jl_obj = _IAI.MultiQuestionnaire_convert(*args)
         super().__init__(jl_obj)
 
 
 class MultiTreePlot(AbstractVisualization):
-    """Specify an interactive tree visualization of multiple tree learners as
-    specified by `questions`
+    """Specify an interactive tree visualization of multiple tree learners
 
     Julia Equivalent:
     `IAI.MultiTreePlot <https://docs.interpretable.ai/v2.0.0/IAITrees/reference/#IAI.MultiTreePlot>`
 
     Examples
     --------
-    >>> MultiTreePlot(questions)
-
-    Parameters
-    ----------
-    The questions to visualize. Refer to the
+    Constructs an interactive tree visualization using multiple tree learners
+    from specified questions. Refer to the
     `documentation on advanced tree visualization <https://docs.interpretable.ai/v2.0.0/IAI-Python/julia/#Python-Interactive-Visualizations-1>`
     for more information.
 
+    >>> MultiTreePlot(questions)
+
+    Constructs an interactive tree visualization containing the final fitted
+    learner from trained grid search as well as the learner found for each
+    parameter combination.
+
+    >>> MultiTreePlot(grid)
+
     Compatibility
     -------------
     Requires IAI version 1.1 or higher.
     """
-    def __init__(self, questions):
-        _requires_iai_version("1.1.0", "MultiTreePlot")
-        jl_obj = _IAI.MultiTreePlot_convert(questions)
+    def __init__(self, *args):
+        if len(args) > 0 and isinstance(args[0], GridSearch):
+            _requires_iai_version("2.0.0", "MultiTreePlot")
+            args = list(args)
+            grid = args.pop(0)
+            jl_obj = _IAI.MultiQuestionnaire_convert(grid._jl_obj, *args)
+        else:
+            _requires_iai_version("1.1.0", "MultiTreePlot")
+            jl_obj = _IAI.MultiTreePlot_convert(*args)
         super().__init__(jl_obj)
